@@ -1,4 +1,9 @@
 package TestsFor::Fail;
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Test::Class::Moose;
 
 sub test_a_good {
