@@ -1,17 +1,21 @@
 package TestsFor::Basic::Role;
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Test::Class::Moose::Role;
 
 sub test_in_a_role {
-    pass "This is picked up from role";
+    pass 'This is picked up from role';
 }
 
 sub in_a_role_with_tags : Tags(first) {
-    fail "We should never see this test";
+    fail 'We should never see this test';
 }
 
 sub test_in_a_role_with_tags : Tags(second) {
-    pass "We should see this test";
+    pass 'We should see this test';
 }
 
 1;
